@@ -31,7 +31,9 @@ class audio_oss_sink;
 typedef boost::shared_ptr<audio_oss_sink> audio_oss_sink_sptr;
 
 audio_oss_sink_sptr
-audio_oss_make_sink (int sampling_freq, const std::string dev = "");
+audio_oss_make_sink (int sampling_rate,
+		     const std::string dev = "",
+		     bool ok_to_block = true);
 
 /*!
  * \brief audio sink using OSS
@@ -42,23 +44,23 @@ audio_oss_make_sink (int sampling_freq, const std::string dev = "");
 
 class audio_oss_sink : public gr_sync_block {
   friend audio_oss_sink_sptr
-  audio_oss_make_sink (int sampling_freq, const std::string device_name);
+  audio_oss_make_sink (int sampling_rate, const std::string device_name, bool ok_to_block);
 
-  int		d_sampling_freq;
+  int		d_sampling_rate;
   std::string	d_device_name;
   int		d_fd;
   short	       *d_buffer;
   int		d_chunk_size;
 
  protected:
-  audio_oss_sink (int sampling_freq, const std::string device_name = "");
+  audio_oss_sink (int sampling_rate, const std::string device_name = "", bool ok_to_block = true);
 
  public:
   ~audio_oss_sink ();
   
   int work (int noutput_items,
-		  gr_vector_const_void_star &input_items,
-		  gr_vector_void_star &output_items);
+	    gr_vector_const_void_star &input_items,
+	    gr_vector_void_star &output_items);
 };
 
 #endif /* INCLUDED_AUDIO_OSS_SINK_H */
