@@ -26,6 +26,7 @@
 
 #include <audio_oss_source.h>
 #include <gr_io_signature.h>
+#include <gr_prefs.h>
 #include <sys/soundcard.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
@@ -37,22 +38,26 @@
 #include <stdexcept>
 
 
-static const double CHUNK_TIME = 0.005;		// 5 ms
-
-// FIXME these should query some kind of user preference
-
-static std::string 
+static std::string
 default_device_name ()
 {
-  return "/dev/dsp";
+  return gr_prefs::singleton()->get_string("audio_oss", "default_input_device", "/dev/dsp");
 }
 
-audio_oss_source::audio_oss_source (int sampling_freq,
-				    const std::string device_name)
+audio_oss_source_sptr
+audio_oss_make_source (int sampling_rate, const std::string dev, bool ok_to_block)
+{
+  return audio_oss_source_sptr (new audio_oss_source (sampling_rate, dev, ok_to_block));
+}
+
+
+audio_oss_source::audio_oss_source (int sampling_rate,
+				    const std::string device_name,
+				    bool ok_to_block)
   : gr_sync_block ("audio_oss_source",
 		   gr_make_io_signature (0, 0, 0),
 		   gr_make_io_signature (1, 2, sizeof (float))),
-    d_sampling_freq (sampling_freq),
+    d_sampling_rate (sampling_rate),
     d_device_name (device_name.empty() ? default_device_name() : device_name),
     d_fd (-1), d_buffer (0), d_chunk_size (0)
 {
@@ -62,7 +67,10 @@ audio_oss_source::audio_oss_source (int sampling_freq,
     throw std::runtime_error ("audio_oss_source");
   }
 
-  d_chunk_size = (int) (d_sampling_freq * CHUNK_TIME);
+  double CHUNK_TIME =
+    std::max(0.001, gr_prefs::singleton()->get_double("audio_oss", "latency", 0.005));
+
+  d_chunk_size = (int) (d_sampling_rate * CHUNK_TIME);
   set_output_multiple (d_chunk_size);
 
   d_buffer = new short [d_chunk_size * 2];
@@ -88,14 +96,14 @@ audio_oss_source::audio_oss_source (int sampling_freq,
   }
 
   // set sampling freq
-  int sf = sampling_freq;
+  int sf = sampling_rate;
   if (ioctl (d_fd, SNDCTL_DSP_SPEED, &sf) < 0){
     std::cerr << "audio_oss_source: "
-	      << d_device_name << ": invalid sampling_freq "
-	      << sampling_freq << "\n";
-    sampling_freq = 8000;
+	      << d_device_name << ": invalid sampling_rate "
+	      << sampling_rate << "\n";
+    sampling_rate = 8000;
     if (ioctl (d_fd, SNDCTL_DSP_SPEED, &sf) < 0){
-      std::cerr << "audio_oss_source: failed to set sampling_freq to 8000\n";
+      std::cerr << "audio_oss_source: failed to set sampling_rate to 8000\n";
       throw std::runtime_error ("audio_oss_source");
     }
   }
@@ -107,13 +115,6 @@ audio_oss_source::~audio_oss_source ()
   delete [] d_buffer;
 }
 
-audio_oss_source_sptr
-audio_oss_make_source (int sampling_freq, const std::string dev)
-{
-  return audio_oss_source_sptr (new audio_oss_source (sampling_freq, dev));
-}
-
-
 int
 audio_oss_source::work (int noutput_items,
 			gr_vector_const_void_star &input_items,
@@ -127,7 +128,6 @@ audio_oss_source::work (int noutput_items,
 
   // To minimize latency, never return more than CHUNK_TIME
   // worth of samples per call to work.  
-  // FIXME, we need an API to set this value
 
   noutput_items = std::min (noutput_items, d_chunk_size);
 
